# -*- coding: utf-8 -*-
import logging
from datetime import datetime

from sqlalchemy import Column, String, Integer, Text, DateTime, Boolean, SmallInteger
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from zebe.module import REMIND_DB_FILE_PATH

# 定义数据库路径
engine = create_engine('sqlite:///' + REMIND_DB_FILE_PATH, echo=True)
RemindModelBase = declarative_base()


# 提醒
class Remind(RemindModelBase):
    __tablename__ = 'remind'
    id = Column(Integer, primary_key=True, autoincrement=True, index=True)  # ID
    title = Column(String(40), default="", nullable=False)  # 提醒标题
    content = Column(Text, default="", nullable=False)  # 提醒内容
    sound = Column(String(300), default="", nullable=False)  # 提醒声音
    mode = Column(String(8), default='', nullable=False, index=True)  # 模式（CRON表达式=cron，周期间隔=interval）
    cron_day_of_week = Column(String(30), default='', nullable=False)  # CRON周表达式
    cron_hour = Column(String(30), default='', nullable=False)  # CRON小时表达式
    cron_minute = Column(String(30), default='', nullable=False)  # CRON分钟表达式
    cron_second = Column(String(30), default='', nullable=False)  # CRON秒表达式
    receiver_email = Column(Text, default="", nullable=False)  # 接收者邮箱
    receiver_phone = Column(Text, default="", nullable=False)  # 接收者电话
    receiver_wechat = Column(Text, default="", nullable=False)  # 接收者微信
    is_enable = Column(SmallInteger, default=0, nullable=False, index=True)  # 是否有效（0=否 1=是）
    create_time = Column(DateTime, default=datetime.now(), nullable=False)  # 创建时间
    last_trigger_time = Column(DateTime)  # 最后触发时间
    finish_time = Column(DateTime)  # 完成时间

    def __repr__(self):
        return "<Remind(title='%s', receiver_email='%s')>" % (self.title, self.receiver_email)


# 初始化数据引擎
RemindModelBase.metadata.create_all(engine)
RemindModelSession = sessionmaker(bind=engine)
logging.debug("初始化数据引擎 -> 成功")



# -*- coding: utf-8 -*-
from sqlalchemy import distinct

from zebe.module.memcard import MemoryCard, MemoryCardModelSession
from zebe.service.base import ModelBaseService


# 秒记卡服务
class MemoryCardService(ModelBaseService):

    def __init__(self):
        super().__init__(MemoryCard, MemoryCardModelSession)

    # 按分类统计
    def count_all_by_type(self, type_name):
        result = self.session.query(self.entity).filter(self.entity.type == type_name).count()
        self.session.close()
        return result

    # 查询所有分类
    def find_all_types(self):
        result = self.session.query(distinct(self.entity.type)).all()
        self.session.close()
        types = []
        for r in result:
            types.append(r[0])
        return types

    # 通过类型查询
    def find_by_type(self, type_name):
        result = self.session.query(self.entity).filter(self.entity.type == type_name).all()
        self.session.close()
        return result

    # 通过key查询单张秒记卡
    def find_one_by_key(self, key):
        result = self.session.query(self.entity).filter(self.entity.key == key).one_or_none()
        self.session.close()
        return result



# -*- coding: utf-8 -*-
from zebe.module.blog import ZebeBlogArticle, BlogModelSession, CdrVbaBlogArticle, CdrVbaBlogSubscriber
from zebe.service.base import ModelBaseService


# Zebe博客文章服务
class ZebeBlogArticleService(ModelBaseService):

    def __init__(self):
        super().__init__(ZebeBlogArticle, BlogModelSession)


# CorelDrawVBA博客文章服务
class CdrVbaBlogArticleService(ModelBaseService):

    def __init__(self):
        super().__init__(CdrVbaBlogArticle, BlogModelSession)


# CorelDrawVBA博客订阅者服务
class CdrVbaBlogSubscriberService(ModelBaseService):

    def __init__(self):
        super().__init__(CdrVbaBlogSubscriber, BlogModelSession)



# -*- coding: utf-8 -*-
from zebe.module.wechat import WechatModelSession, WeChatMiaoJiUser, WeChatZebeUser, WeChatMiaoJiUserMessage, \
    WeChatZebeUserMessage
from zebe.service.base import ModelBaseService


# 秒记先生微信用户服务
class WeChatMiaoJiUserService(ModelBaseService):

    def __init__(self):
        super().__init__(WeChatMiaoJiUser, WechatModelSession)


# 秒记先生微信用户消息服务
class WeChatMiaoJiUserMessageService(ModelBaseService):
    def __init__(self):
        super().__init__(WeChatMiaoJiUserMessage, WechatModelSession)


# Zebe个人微信用户服务
class WeChatZebeUserService(ModelBaseService):

    def __init__(self):
        super().__init__(WeChatZebeUser, WechatModelSession)


# Zebe个人微信用户消息服务
class WeChatZebeUserMessageService(ModelBaseService):

    def __init__(self):
        super().__init__(WeChatZebeUserMessage, WechatModelSession)


# -*- coding: utf-8 -*-
import logging
from datetime import datetime

from sqlalchemy import Column, String, Text, DateTime, Integer
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from zebe.module import MEMCARD_DB_FILE_PATH

# 定义数据库路径
engine = create_engine('sqlite:///' + MEMCARD_DB_FILE_PATH, echo=True)
MemoryCardModelBase = declarative_base()


# 秒记卡
class MemoryCard(MemoryCardModelBase):
    __tablename__ = 'memcard'
    id = Column(Integer, primary_key=True, autoincrement=True, index=True)  # ID
    key = Column(String(20), default="", index=True)  # 记忆键
    content = Column(Text, default="")  # 记忆内容
    target = Column(String(100), default="")  # 记忆目标
    description = Column(Text, default="")  # 记忆描述
    type = Column(String(20), default="", index=True)  # 分类
    image = Column(String(300), default="")  # 辅助图像
    image_gif = Column(String(300), default="")  # 辅助图像(动态)
    sound = Column(String(300), default="")  # 辅助声音
    url = Column(String(500), default="")  # 跳转链接
    filename = Column(String(60), default="")  # 文件名
    create_time = Column(DateTime, default=datetime.now())  # 创建时间

    def __repr__(self):
        return "<MemoryCard(name='%s')>" % (self.name)


# 初始化数据引擎
MemoryCardModelBase.metadata.create_all(engine)
MemoryCardModelSession = sessionmaker(bind=engine)
logging.debug("初始化数据引擎 -> 成功")



# -*- coding: utf-8 -*-
from zebe.module.diary import Diary, DiaryModelSession
from zebe.service.base import ModelBaseService


# 日记服务
class DiaryService(ModelBaseService):

    def __init__(self):
        super().__init__(Diary, DiaryModelSession)

    # 通过标题查找一篇日记
    def find_one_by_title(self, title):
        result = None
        if title is not None:
            result = self.session.query(self.entity).filter(self.entity.title == title).one_or_none()
            self.session.close()
        return result



# -*- coding: utf-8 -*-
import logging
from datetime import datetime

from sqlalchemy import Column, String, DateTime, Integer, Text
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from zebe.module import WECHAT_DB_FILE_PATH

# 定义数据库路径
engine = create_engine('sqlite:///' + WECHAT_DB_FILE_PATH, echo=True)
WeChatModelBase = declarative_base()


# 秒记先生微信用户
class WeChatMiaoJiUser(WeChatModelBase):
    __tablename__ = 'wechat_miaoji_user'
    id = Column(String(28), primary_key=True)  # ID（和openId相同）
    realname = Column(String(20), nullable=False, default='')  # 真实姓名
    nickname = Column(String(32), nullable=False, default='')  # 昵称
    wxid = Column(String(20), nullable=False, default='')  # 微信号
    follow_time = Column(DateTime, nullable=False, default=datetime.now())  # 关注时间
    unfollow_time = Column(DateTime)  # 取消关注时间

    def __repr__(self):
        return "<WeChatMiaoJiUser(id='%s')>" % (self.id)


# 秒记先生微信用户发来的消息
class WeChatMiaoJiUserMessage(WeChatModelBase):
    __tablename__ = 'wechat_miaoji_user_msg'
    id = Column(Integer, primary_key=True)  # ID
    type = Column(String(10), default="", nullable=False, index=True)  # 消息类型
    content = Column(Text, default="", nullable=False)  # 文本内容
    voice = Column(Text, default="", nullable=False)  # 语音内容
    link = Column(String(300), default="", nullable=False)  # 链接
    source = Column(String(40), default="", nullable=False)  # 消息来源
    reply = Column(Text, default="", nullable=False)  # 回复内容
    create_time = Column(DateTime, default=datetime.now(), nullable=False)  # 发送时间

    def __repr__(self):
        return "<WeChatMiaoJiUserMessage(content='%s')>" % (self.content)


# Zebe个人微信用户
class WeChatZebeUser(WeChatModelBase):
    __tablename__ = 'wechat_zebe_user'
    id = Column(String(28), primary_key=True)  # ID（和openId相同）
    realname = Column(String(20), nullable=False, default='')  # 真实姓名
    nickname = Column(String(32), nullable=False, default='')  # 昵称
    wxid = Column(String(20), nullable=False, default='')  # 微信号
    follow_time = Column(DateTime, nullable=False, default=datetime.now())  # 关注时间
    unfollow_time = Column(DateTime)  # 取消关注时间

    def __repr__(self):
        return "<WeChatZebeUser(id='%s')>" % (self.id)


# Zebe个人微信用户发来的消息
class WeChatZebeUserMessage(WeChatModelBase):
    __tablename__ = 'wechat_zebe_user_msg'
    id = Column(Integer, primary_key=True)  # ID
    type = Column(String(10), default="", nullable=False, index=True)  # 消息类型
    content = Column(Text, default="", nullable=False)  # 文本内容
    voice = Column(Text, default="", nullable=False)  # 语音内容
    link = Column(String(300), default="", nullable=False)  # 链接
    source = Column(String(40), default="", nullable=False)  # 消息来源
    reply = Column(Text, default="", nullable=False)  # 回复内容
    create_time = Column(DateTime, default=datetime.now(), nullable=False)  # 发送时间

    def __repr__(self):
        return "<WeChatZebeUserMessage(content='%s')>" % (self.content)


# 初始化数据引擎
WeChatModelBase.metadata.create_all(engine)
WechatModelSession = sessionmaker(bind=engine)
logging.debug("初始化数据引擎 -> 成功")



# -*- coding: utf-8 -*-
from zebe.module.app import App, AppModelSession
from zebe.service.base import ModelBaseService


# 应用服务
class AppService(ModelBaseService):

    def __init__(self):
        super().__init__(App, AppModelSession)

    # 通过名称查找一个应用
    def find_one_by_name(self, name):
        result = None
        if name is not None:
            result = self.session.query(self.entity).filter(self.entity.name == name).one_or_none()
            self.session.close()
        return result
